caellion-python-commons: caellion.pycommons.stringutil.formatters.InvalidDurationException Class Reference

caellion-python-commons

caellion.pycommons.stringutil.formatters.InvalidDurationException Class Reference

This exception is raised whenever provided duration is zero or negative. More...

Inheritance diagram for caellion.pycommons.stringutil.formatters.InvalidDurationException:

## Detailed Description

This exception is raised whenever provided duration is zero or negative.

Definition at line 8 of file formatters.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/stringutil/formatters.py